@@ -3,8 +3,8 @@
 Unit tests for pypvwatts.
 
 """
-from pypvwatts import PVWatts, PVWattsResult
-from pvwattserror import PVWattsValidationError
+from .pypvwatts import PVWatts, PVWattsResult
+from .pvwattserror import PVWattsValidationError
 
 import unittest
 import json
@@ -198,7 +198,6 @@ class Test(unittest.TestCase):
             system_capacity=4, module_type=1, array_type=1,
             azimuth=190, tilt=30, dataset='tmy2',
             losses=0.13, lat=40, lon=-105)
-        print results.raw
         self.assert_results(results)
 
     def test_pypvwatts_instance(self):
@@ -211,11 +210,11 @@ class Test(unittest.TestCase):
         self.assert_results(results)
 
     def assert_results(self, results):
-        self.assertEqual(results.ac_annual, 7283.0498046875)
+        self.assertEqual(results.ac_annual, 7201.1396484375)
         self.assertEqual(results.solrad_annual, 5.446694850921631)
         self.assertEqual(results.station_info['city'], 'BOULDER')
-        self.assertIn(708.9085083007812, results.dc_monthly)
-        self.assertIn(183.11537170410156, results.poa_monthly)
+        self.assertIn(501.930908203125, results.dc_monthly)
+        self.assertIn(180.2367248535156, results.poa_monthly)
         self.assertIn(6.103845596313477, results.solrad_monthly)
 
 
